fn validate_max_output_tokens(input: &NewChatbotConf) -> ModelResult<()>Expand description
Rejects configurations whose max_output_tokens is too small to produce a usable response.
fn validate_max_output_tokens(input: &NewChatbotConf) -> ModelResult<()>Rejects configurations whose max_output_tokens is too small to produce a usable response.